@@ -81,7 +81,7 @@ class FilterCollectionFilter(Filter):
             invert = flt.pop("invert", False)
             flt_key = list(flt.keys())[0]
             flt_val = flt[flt_key]
-            filter = filter_coll.get_filters()[flt_key]
+            filter = filter_coll.filters[flt_key]
 
             new_qs = filter.filter(qs, flt_val)
 
@@ -99,7 +99,7 @@ class FilterCollectionOrdering(Filter):
 
         assert len(ord) == 1
         filt_name = list(ord.keys())[0]
-        filter = filter_coll.get_filters()[filt_name]
+        filter = filter_coll.filters[filt_name]
         qs, field = filter.get_ordering_value(qs, ord[filt_name])
 
         # Normally, people use ascending order, and in this context it seems
@@ -384,6 +384,8 @@ class OrderingFilter(OrderingFilter):
             "modified_at",
             "created_by_user",
             "created_by_group",
+            "modified_by_user",
+            "modified_by_group",
             *[f"meta_{f}" for f in settings.META_FIELDS],
         )
 
@@ -423,6 +425,8 @@ class IntegerFilter(Filter):
 class FilterSet(GrapheneFilterSetMixin, FilterSet):
     created_by_user = CharFilter()
     created_by_group = CharFilter()
+    modified_by_user = CharFilter()
+    modified_by_group = CharFilter()
 
     created_before = DateTimeFilter(
         field_name="created_at",
