@@ -22,7 +22,7 @@ class QuestionJexlField(serializers.JexlField):
 class SaveFormSerializer(serializers.ModelSerializer):
     class Meta:
         model = models.Form
-        fields = ("slug", "name", "description", "meta", "is_archived", "is_published")
+        fields = ["slug", "name", "description", "meta", "is_archived", "is_published"]
 
 
 class CopyFormSerializer(serializers.ModelSerializer):
@@ -38,7 +38,7 @@ class CopyFormSerializer(serializers.ModelSerializer):
 
     class Meta:
         model = models.Form
-        fields = ("slug", "name", "description", "source", "is_published")
+        fields = ["slug", "name", "description", "source", "is_published"]
 
 
 class AddFormQuestionSerializer(serializers.ModelSerializer):
@@ -67,7 +67,7 @@ class AddFormQuestionSerializer(serializers.ModelSerializer):
         return instance
 
     class Meta:
-        fields = ("form", "question")
+        fields = ["form", "question"]
         model = models.Form
 
 
@@ -84,7 +84,7 @@ class RemoveFormQuestionSerializer(serializers.ModelSerializer):
         return instance
 
     class Meta:
-        fields = ("form", "question")
+        fields = ["form", "question"]
         model = models.Form
 
 
@@ -117,7 +117,7 @@ class ReorderFormQuestionsSerializer(serializers.ModelSerializer):
         return instance
 
     class Meta:
-        fields = ("form", "questions")
+        fields = ["form", "questions"]
         model = models.Form
 
 
@@ -146,6 +146,8 @@ class CopyQuestionSerializer(serializers.ModelSerializer):
                 option=question_option.option,
                 created_by_user=user.username,
                 created_by_group=user.group,
+                modified_by_user=user.username,
+                modified_by_group=user.group,
             )
             for sort, question_option in enumerate(
                 reversed(models.QuestionOption.objects.filter(question=source)), start=1
@@ -158,13 +160,12 @@ class CopyQuestionSerializer(serializers.ModelSerializer):
 
     class Meta:
         model = models.Question
-        fields = ("slug", "label", "source")
+        fields = ["slug", "label", "source"]
 
 
 class SaveQuestionSerializer(serializers.ModelSerializer):
     is_hidden = QuestionJexlField(required=False)
     is_required = QuestionJexlField(required=False)
-    default_answer = PrimaryKeyRelatedField(read_only=True)
 
     def validate(self, data):
         validators.QuestionValidator().validate(data)
@@ -172,7 +173,7 @@ class SaveQuestionSerializer(serializers.ModelSerializer):
 
     class Meta:
         model = models.Question
-        fields = (
+        fields = [
             "slug",
             "label",
             "info_text",
@@ -180,8 +181,7 @@ class SaveQuestionSerializer(serializers.ModelSerializer):
             "is_hidden",
             "meta",
             "is_archived",
-            "default_answer",
-        )
+        ]
 
 
 class SaveTextQuestionSerializer(SaveQuestionSerializer):
@@ -194,12 +194,12 @@ class SaveTextQuestionSerializer(SaveQuestionSerializer):
         return super().validate(data)
 
     class Meta(SaveQuestionSerializer.Meta):
-        fields = SaveQuestionSerializer.Meta.fields + (
+        fields = SaveQuestionSerializer.Meta.fields + [
             "min_length",
             "max_length",
             "placeholder",
             "format_validators",
-        )
+        ]
 
 
 class SaveTextareaQuestionSerializer(SaveQuestionSerializer):
@@ -212,12 +212,12 @@ class SaveTextareaQuestionSerializer(SaveQuestionSerializer):
         return super().validate(data)
 
     class Meta(SaveQuestionSerializer.Meta):
-        fields = SaveQuestionSerializer.Meta.fields + (
+        fields = SaveQuestionSerializer.Meta.fields + [
             "min_length",
             "max_length",
             "placeholder",
             "format_validators",
-        )
+        ]
 
 
 class SaveDateQuestionSerializer(SaveQuestionSerializer):
@@ -239,6 +239,8 @@ class SaveQuestionOptionsMixin(object):
                 option=option,
                 created_by_user=user.username,
                 created_by_group=user.group,
+                modified_by_user=user.username,
+                modified_by_group=user.group,
             )
             for sort, option in enumerate(reversed(options), start=1)
         ]
@@ -273,7 +275,7 @@ class SaveMultipleChoiceQuestionSerializer(
         return super().validate(data)
 
     class Meta(SaveQuestionSerializer.Meta):
-        fields = SaveQuestionSerializer.Meta.fields + ("options",)
+        fields = SaveQuestionSerializer.Meta.fields + ["options"]
 
 
 class SaveChoiceQuestionSerializer(SaveQuestionOptionsMixin, SaveQuestionSerializer):
@@ -286,7 +288,7 @@ class SaveChoiceQuestionSerializer(SaveQuestionOptionsMixin, SaveQuestionSeriali
         return super().validate(data)
 
     class Meta(SaveQuestionSerializer.Meta):
-        fields = SaveQuestionSerializer.Meta.fields + ("options",)
+        fields = SaveQuestionSerializer.Meta.fields + ["options"]
 
 
 class SaveDynamicChoiceQuestionSerializer(SaveQuestionSerializer):
@@ -297,7 +299,7 @@ class SaveDynamicChoiceQuestionSerializer(SaveQuestionSerializer):
         return super().validate(data)
 
     class Meta(SaveQuestionSerializer.Meta):
-        fields = SaveQuestionSerializer.Meta.fields + ("data_source",)
+        fields = SaveQuestionSerializer.Meta.fields + ["data_source"]
 
 
 class SaveDynamicMultipleChoiceQuestionSerializer(SaveQuestionSerializer):
@@ -308,7 +310,7 @@ class SaveDynamicMultipleChoiceQuestionSerializer(SaveQuestionSerializer):
         return super().validate(data)
 
     class Meta(SaveQuestionSerializer.Meta):
-        fields = SaveQuestionSerializer.Meta.fields + ("data_source",)
+        fields = SaveQuestionSerializer.Meta.fields + ["data_source"]
 
 
 class SaveFloatQuestionSerializer(SaveQuestionSerializer):
@@ -334,11 +336,11 @@ class SaveFloatQuestionSerializer(SaveQuestionSerializer):
         return super().validate(data)
 
     class Meta(SaveQuestionSerializer.Meta):
-        fields = SaveQuestionSerializer.Meta.fields + (
+        fields = SaveQuestionSerializer.Meta.fields + [
             "min_value",
             "max_value",
             "placeholder",
-        )
+        ]
 
 
 class SaveIntegerQuestionSerializer(SaveQuestionSerializer):
@@ -364,11 +366,11 @@ class SaveIntegerQuestionSerializer(SaveQuestionSerializer):
         return super().validate(data)
 
     class Meta(SaveQuestionSerializer.Meta):
-        fields = SaveQuestionSerializer.Meta.fields + (
+        fields = SaveQuestionSerializer.Meta.fields + [
             "min_value",
             "max_value",
             "placeholder",
-        )
+        ]
 
 
 class SaveTableQuestionSerializer(SaveQuestionSerializer):
@@ -383,7 +385,7 @@ class SaveTableQuestionSerializer(SaveQuestionSerializer):
         return super().validate(data)
 
     class Meta(SaveQuestionSerializer.Meta):
-        fields = SaveQuestionSerializer.Meta.fields + ("row_form",)
+        fields = SaveQuestionSerializer.Meta.fields + ["row_form"]
 
 
 class SaveFormQuestionSerializer(SaveQuestionSerializer):
@@ -396,7 +398,7 @@ class SaveFormQuestionSerializer(SaveQuestionSerializer):
         return super().validate(data)
 
     class Meta(SaveQuestionSerializer.Meta):
-        fields = SaveQuestionSerializer.Meta.fields + ("sub_form",)
+        fields = SaveQuestionSerializer.Meta.fields + ["sub_form"]
 
 
 class SaveFileQuestionSerializer(SaveQuestionSerializer):
@@ -416,7 +418,7 @@ class SaveStaticQuestionSerializer(SaveQuestionSerializer):
         return super().validate(data)
 
     class Meta(SaveQuestionSerializer.Meta):
-        fields = (
+        fields = [
             "label",
             "slug",
             "info_text",
@@ -424,7 +426,7 @@ class SaveStaticQuestionSerializer(SaveQuestionSerializer):
             "meta",
             "is_archived",
             "static_content",
-        )
+        ]
 
 
 class SaveCalculatedFloatQuestionSerializer(SaveQuestionSerializer):
@@ -435,12 +437,14 @@ class SaveCalculatedFloatQuestionSerializer(SaveQuestionSerializer):
         return super().validate(data)
 
     class Meta(SaveQuestionSerializer.Meta):
-        fields = SaveQuestionSerializer.Meta.fields + ("calc_expression",)
+        fields = SaveQuestionSerializer.Meta.fields + [
+            "calc_expression",
+        ]
 
 
 class SaveOptionSerializer(serializers.ModelSerializer):
     class Meta:
-        fields = ("slug", "label", "is_archived", "meta")
+        fields = ["slug", "label", "is_archived", "meta"]
         model = models.Option
 
 
@@ -455,7 +459,7 @@ class CopyOptionSerializer(serializers.ModelSerializer):
         return super().create(validated_data)
 
     class Meta:
-        fields = ("slug", "label", "source")
+        fields = ["slug", "label", "source"]
         model = models.Option
 
 
@@ -467,7 +471,11 @@ class DocumentSerializer(serializers.ModelSerializer):
 
     class Meta:
         model = models.Document
-        fields = ("id", "form", "meta")
+        fields = [
+            "id",
+            "form",
+            "meta",
+        ]
 
 
 class SaveAnswerSerializer(serializers.ModelSerializer):
@@ -485,11 +493,11 @@ class SaveAnswerSerializer(serializers.ModelSerializer):
 
     @transaction.atomic
     def update(self, instance, validated_data):
-        return domain_logic.SaveAnswerLogic.update(validated_data, instance)
+        return domain_logic.SaveAnswerLogic.update(instance, validated_data)
 
     class Meta:
         model = models.Answer
-        fields = ("question", "document", "meta", "value")
+        fields = ["question", "document", "meta", "value"]
 
 
 class SaveDocumentStringAnswerSerializer(SaveAnswerSerializer):
@@ -545,7 +553,9 @@ class SaveDocumentFileAnswerSerializer(SaveAnswerSerializer):
     value_id = PrimaryKeyRelatedField(read_only=True, source="file", required=False)
 
     class Meta(SaveAnswerSerializer.Meta):
-        fields = SaveAnswerSerializer.Meta.fields + ("value_id",)
+        fields = SaveAnswerSerializer.Meta.fields + [
+            "value_id",
+        ]
 
 
 class RemoveAnswerSerializer(serializers.ModelSerializer):
@@ -559,7 +569,9 @@ class RemoveAnswerSerializer(serializers.ModelSerializer):
         return instance
 
     class Meta:
-        fields = ("answer",)
+        fields = [
+            "answer",
+        ]
         model = models.Answer
 
 
@@ -575,11 +587,11 @@ class SaveDefaultAnswerSerializer(serializers.ModelSerializer):
         )
 
     def update(self, instance, validated_data):
-        return domain_logic.SaveDefaultAnswerLogic.update(validated_data, instance)
+        return domain_logic.SaveDefaultAnswerLogic.update(instance, validated_data)
 
     class Meta:
         model = models.Answer
-        fields = ("question", "meta", "value")
+        fields = ["question", "meta", "value"]
 
 
 class SaveDefaultStringAnswerSerializer(SaveDefaultAnswerSerializer):
@@ -639,7 +651,9 @@ class RemoveDefaultAnswerSerializer(serializers.ModelSerializer):
         return instance
 
     class Meta:
-        fields = ("question",)
+        fields = [
+            "question",
+        ]
         model = models.Question
 
 
@@ -661,7 +675,7 @@ class RemoveDocumentSerializer(serializers.ModelSerializer):
         return instance
 
     class Meta:
-        fields = ("document",)
+        fields = ["document"]
         model = models.Document
 
 
@@ -672,8 +686,11 @@ class CopyDocumentSerializer(serializers.ModelSerializer):
 
     @transaction.atomic
     def create(self, validated_data):
-        return validated_data["source"].copy()
+        return validated_data["source"].copy(
+            family=None,
+            user=self.context["request"].user,
+        )
 
     class Meta:
         model = models.Document
-        fields = ("source",)
+        fields = ["source"]
